@@ -1,7 +1,7 @@
 // padthv1_ui.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,15 +28,15 @@
 // padthv1_ui - decl.
 //
 
-padthv1_ui::padthv1_ui ( padthv1 *pSynth, bool bPlugin )
-	: m_pSynth(pSynth), m_bPlugin(bPlugin)
+padthv1_ui::padthv1_ui ( padthv1 *pPadth, bool bPlugin )
+	: m_pPadth(pPadth), m_bPlugin(bPlugin)
 {
 }
 
 
 padthv1 *padthv1_ui::instance (void) const
 {
-	return m_pSynth;
+	return m_pPadth;
 }
 
 
@@ -48,133 +48,139 @@ bool padthv1_ui::isPlugin (void) const
 
 padthv1_sample *padthv1_ui::sample ( int sid ) const
 {
-	return m_pSynth->sample(sid);
+	return m_pPadth->sample(sid);
+}
+
+
+bool padthv1_ui::newPreset (void)
+{
+	return padthv1_param::newPreset(m_pPadth);
 }
 
 
 bool padthv1_ui::loadPreset ( const QString& sFilename )
 {
-	return padthv1_param::loadPreset(m_pSynth, sFilename);
+	return padthv1_param::loadPreset(m_pPadth, sFilename);
 }
 
 bool padthv1_ui::savePreset ( const QString& sFilename )
 {
-	return padthv1_param::savePreset(m_pSynth, sFilename);
+	return padthv1_param::savePreset(m_pPadth, sFilename);
 }
 
 
 void padthv1_ui::setParamValue ( padthv1::ParamIndex index, float fValue )
 {
-	m_pSynth->setParamValue(index, fValue);
+	m_pPadth->setParamValue(index, fValue);
 }
 
 
 float padthv1_ui::paramValue ( padthv1::ParamIndex index ) const
 {
-	return m_pSynth->paramValue(index);
+	return m_pPadth->paramValue(index);
 }
 
 
 padthv1_controls *padthv1_ui::controls (void) const
 {
-	return m_pSynth->controls();
+	return m_pPadth->controls();
 }
 
 
 padthv1_programs *padthv1_ui::programs (void) const
 {
-	return m_pSynth->programs();
+	return m_pPadth->programs();
 }
 
 
 void padthv1_ui::reset (void)
 {
-	return m_pSynth->reset();
+	return m_pPadth->reset();
 }
 
 
 void padthv1_ui::updatePreset ( bool bDirty )
 {
-	m_pSynth->updatePreset(bDirty);
+	m_pPadth->updatePreset(bDirty);
 }
 
 
 void padthv1_ui::midiInEnabled ( bool bEnabled )
 {
-	m_pSynth->midiInEnabled(bEnabled);
+	m_pPadth->midiInEnabled(bEnabled);
 }
 
 
 uint32_t padthv1_ui::midiInCount (void)
 {
-	return m_pSynth->midiInCount();
+	return m_pPadth->midiInCount();
 }
 
 
 void padthv1_ui::directNoteOn ( int note, int vel )
 {
-	m_pSynth->directNoteOn(note, vel);
+	m_pPadth->directNoteOn(note, vel);
 }
 
 
 void padthv1_ui::setTuningEnabled ( bool enabled )
 {
-	m_pSynth->setTuningEnabled(enabled);
+	m_pPadth->setTuningEnabled(enabled);
 }
 
 bool padthv1_ui::isTuningEnabled (void) const
 {
-	return m_pSynth->isTuningEnabled();
+	return m_pPadth->isTuningEnabled();
 }
 
 
 void padthv1_ui::setTuningRefPitch ( float refPitch )
 {
-	m_pSynth->setTuningRefPitch(refPitch);
+	m_pPadth->setTuningRefPitch(refPitch);
 }
 
 float padthv1_ui::tuningRefPitch (void) const
 {
-	return m_pSynth->tuningRefPitch();
+	return m_pPadth->tuningRefPitch();
 }
 
 
 void padthv1_ui::setTuningRefNote ( int refNote )
 {
-	m_pSynth->setTuningRefNote(refNote);
+	m_pPadth->setTuningRefNote(refNote);
 }
 
 int padthv1_ui::tuningRefNote (void) const
 {
-	return m_pSynth->tuningRefNote();
+	return m_pPadth->tuningRefNote();
 }
 
 
 void padthv1_ui::setTuningScaleFile ( const char *pszScaleFile )
 {
-	m_pSynth->setTuningScaleFile(pszScaleFile);
+	m_pPadth->setTuningScaleFile(pszScaleFile);
 }
 
 const char *padthv1_ui::tuningScaleFile (void) const
 {
-	return m_pSynth->tuningScaleFile();
+	return m_pPadth->tuningScaleFile();
 }
 
 
 void padthv1_ui::setTuningKeyMapFile ( const char *pszKeyMapFile )
 {
-	m_pSynth->setTuningKeyMapFile(pszKeyMapFile);
+	m_pPadth->setTuningKeyMapFile(pszKeyMapFile);
 }
 
 const char *padthv1_ui::tuningKeyMapFile (void) const
 {
-	return m_pSynth->tuningKeyMapFile();
+	return m_pPadth->tuningKeyMapFile();
 }
 
 
 void padthv1_ui::resetTuning (void)
 {
-	m_pSynth->resetTuning();
+	m_pPadth->resetTuning();
 }
 
 
