@@ -580,13 +580,7 @@ padthv1widget::padthv1widget ( QWidget *pParent )
 		SLOT(helpAboutQt()));
 
 	// General knob/dial  behavior init...
-	padthv1_config *pConfig = padthv1_config::getInstance();
-	if (pConfig) {
-		padthv1widget_dial::setDialMode(
-			padthv1widget_dial::DialMode(pConfig->iKnobDialMode));
-		padthv1widget_edit::setEditMode(
-			padthv1widget_edit::EditMode(pConfig->iKnobEditMode));
-	}
+	updateConfig();
 
 	// Epilog.
 	// QWidget::adjustSize();
@@ -1007,6 +1001,10 @@ void padthv1widget::newPreset (void)
 	resetParamKnobs();
 	resetParamValues();
 
+	padthv1_ui *pSynthUi = ui_instance();
+	if (pSynthUi)
+		pSynthUi->newPreset();
+
 	m_ui.StatusBar->showMessage(tr("New preset"), 5000);
 	updateDirtyPreset(false);
 }
@@ -1097,6 +1095,19 @@ bool padthv1widget::queryClose (void)
 }
 
 
+// Update visual configuration.
+void padthv1widget::updateConfig (void)
+{
+	padthv1_config *pConfig = padthv1_config::getInstance();
+	if (pConfig) {
+		padthv1widget_dial::setDialMode(
+			padthv1widget_dial::DialMode(pConfig->iKnobDialMode));
+		padthv1widget_edit::setEditMode(
+			padthv1widget_edit::EditMode(pConfig->iKnobEditMode));
+	}
+}
+
+
 // Preset status updater.
 void padthv1widget::updateLoadPreset ( const QString& sPreset )
 {
